@@ -1,4 +1,4 @@
-from __future__ import with_statement
+
 import time
 from . import portalocker
 
@@ -11,21 +11,18 @@ __all__ = [
     'AlreadyLocked',
 ]
 
+
 class AlreadyLocked(Exception):
     pass
 
+
 class Lock(object):
+
     def __init__(
-            self,
-            filename,
-            mode='a',
-            truncate=0,
-            timeout=DEFAULT_TIMEOUT,
-            check_interval=DEFAULT_CHECK_INTERVAL,
-            fail_when_locked=True,
-        ):
+            self, filename, mode='a', truncate=0, timeout=DEFAULT_TIMEOUT,
+            check_interval=DEFAULT_CHECK_INTERVAL, fail_when_locked=True):
         '''Lock manager with build-in timeout
-        
+
         filename -- filename
         mode -- the open mode, 'a' or 'ab' should be used for writing
         truncate -- use truncate to emulate 'w' mode, None is disabled, 0 is
@@ -34,7 +31,7 @@ class Lock(object):
         check_interval -- check interval while waiting
         fail_when_locked -- after the initial lock failed, return an error
             or lock the file
-        
+
         fail_when_locked is useful when multiple threads/processes can race
         when creating a file. If set to true than the system will wait till
         the lock was acquired and then return an AlreadyLocked exception.
@@ -53,10 +50,13 @@ class Lock(object):
 
         assert 'w' not in mode, 'Mode "w" clears the file before locking'
 
-    def acquire(self, timeout=None, check_interval=None, fail_when_locked=None):
+    def acquire(
+            self, timeout=None, check_interval=None, fail_when_locked=None):
         '''Acquire the locked filehandle'''
         if timeout is None:
             timeout = self.timeout
+        if timeout is None:
+            timeout = 0
 
         if check_interval is None:
             check_interval = self.check_interval
@@ -74,7 +74,7 @@ class Lock(object):
         try:
             # Try to lock
             fh = self._get_lock(fh)
-        except portalocker.LockException, exception:
+        except portalocker.LockException as exception:
             # Try till the timeout is 0
             while timeout > 0:
                 # Wait a bit
@@ -83,21 +83,23 @@ class Lock(object):
 
                 # Try again
                 try:
-                    fh = self._get_lock(fh)
 
-                    # We've got the lock, now return an error if
-                    # fail_when_locked is True or break if not
+                    # We already tried to the get the lock
+                    # If fail_when_locked is true, then stop trying
                     if fail_when_locked:
-                        self._release_lock()
-                        raise AlreadyLocked(*exception)
-                    else:
+                        raise AlreadyLocked(exception)
+
+                    else:  # pragma: no cover
+                        # We've got the lock
+                        fh = self._get_lock(fh)
                         break
+
                 except portalocker.LockException:
                     pass
 
             else:
                 # We got a timeout... reraising
-                raise portalocker.LockException(*exception)
+                raise portalocker.LockException(exception)
 
         # Prepare the filehandle (truncate if needed)
         fh = self._prepare_fh(fh)
@@ -112,7 +114,7 @@ class Lock(object):
     def _get_lock(self, fh):
         '''
         Try to lock the given filehandle
-        
+
         returns LockException if it fails'''
         portalocker.lock(fh, LOCK_METHOD)
         return fh
@@ -135,8 +137,8 @@ class Lock(object):
 
     def __enter__(self):
         self.fh = self.acquire()
+        return self.fh
 
-    def __exit__(self, type, value, tb):
+    def __exit__(self, type_, value, tb):
         if self.fh:
             self.fh.close()
-
